@@ -16,17 +16,16 @@
 
 """Test the lazy_import functionality."""
 
-import linecache
 import os
 import re
 import sys
 
-from .. import errors, lazy_import, osutils
+from .. import lazy_import, osutils
 from . import TestCase, TestCaseInTempDir
 
 
 class InstrumentedReplacer(lazy_import.ScopeReplacer):
-    """Track what actions are done"""
+    """Track what actions are done."""
 
     @staticmethod
     def use_actions(actions):
@@ -60,7 +59,7 @@ class InstrumentedImportReplacer(lazy_import.ImportReplacer):
 
 
 class TestClass:
-    """Just a simple test class instrumented for the test cases"""
+    """Just a simple test class instrumented for the test cases."""
 
     class_member = "class_member"
 
@@ -111,7 +110,7 @@ class TestScopeReplacer(TestCase):
             return TestClass()
 
         try:
-            test_obj1
+            test_obj1  # noqa: B018
         except NameError:
             # test_obj1 shouldn't exist yet
             pass
@@ -153,7 +152,7 @@ class TestScopeReplacer(TestCase):
             return TestClass()
 
         try:
-            test_obj6
+            test_obj6  # noqa: B018
         except NameError:
             # test_obj6 shouldn't exist yet
             pass
@@ -180,7 +179,7 @@ class TestScopeReplacer(TestCase):
         And only that entry even after replacement.
         """
         try:
-            test_scope1
+            test_scope1  # noqa: B018
         except NameError:
             # test_scope1 shouldn't exist yet
             pass
@@ -222,7 +221,7 @@ class TestScopeReplacer(TestCase):
             return TestClass
 
         try:
-            test_class1
+            test_class1  # noqa: B018
         except NameError:
             # test_class2 shouldn't exist yet
             pass
@@ -251,7 +250,7 @@ class TestScopeReplacer(TestCase):
             return TestClass
 
         try:
-            test_class2
+            test_class2  # noqa: B018
         except NameError:
             # test_class2 shouldn't exist yet
             pass
@@ -287,7 +286,7 @@ class TestScopeReplacer(TestCase):
             return func
 
         try:
-            test_func1
+            test_func1  # noqa: B018
         except NameError:
             # test_func1 shouldn't exist yet
             pass
@@ -327,7 +326,7 @@ class TestScopeReplacer(TestCase):
             return TestClass()
 
         try:
-            test_obj2
+            test_obj2  # noqa: B018
         except NameError:
             # test_obj2 shouldn't exist yet
             pass
@@ -392,7 +391,7 @@ class TestScopeReplacer(TestCase):
             return TestClass()
 
         try:
-            test_obj4
+            test_obj4  # noqa: B018
         except NameError:
             # test_obj4 shouldn't exist yet
             pass
@@ -447,7 +446,7 @@ class TestScopeReplacer(TestCase):
         )
 
     def test_replacing_from_own_scope_fails(self):
-        """If a ScopeReplacer tries to replace itself a nice error is given"""
+        """If a ScopeReplacer tries to replace itself a nice error is given."""
         actions = []
         InstrumentedReplacer.use_actions(actions)
         TestClass.use_actions(actions)
@@ -458,7 +457,7 @@ class TestScopeReplacer(TestCase):
             return scope[name]
 
         try:
-            test_obj7
+            test_obj7  # noqa: B018
         except NameError:
             # test_obj7 shouldn't exist yet
             pass
@@ -476,7 +475,7 @@ class TestScopeReplacer(TestCase):
 
 
 class ImportReplacerHelper(TestCaseInTempDir):
-    """Test the ability to have a lazily imported module or object"""
+    """Test the ability to have a lazily imported module or object."""
 
     def setUp(self):
         super().setUp()
@@ -521,7 +520,7 @@ class ImportReplacerHelper(TestCaseInTempDir):
         os.mkdir("base")
         root_path = osutils.pathjoin("base", root_name)
         os.mkdir(root_path)
-        root_init = osutils.pathjoin(root_path, "__init__.py")
+        osutils.pathjoin(root_path, "__init__.py")
         with open(osutils.pathjoin(root_path, "__init__.py"), "w") as f:
             f.write("var1 = 1\ndef func1(a):\n  return a\n")
         mod_path = osutils.pathjoin(root_path, mod_name + ".py")
@@ -547,7 +546,7 @@ class ImportReplacerHelper(TestCaseInTempDir):
 
 class TestImportReplacerHelper(ImportReplacerHelper):
     def test_basic_import(self):
-        """Test that a real import of these modules works"""
+        """Test that a real import of these modules works."""
         sub_mod_path = ".".join([self.root_name, self.sub_name, self.submoda_name])
         root = lazy_import._builtin_import(sub_mod_path, {}, {}, [], 0)
         self.assertEqual(1, root.var1)
@@ -571,9 +570,9 @@ class TestImportReplacerHelper(ImportReplacerHelper):
 
 class TestImportReplacer(ImportReplacerHelper):
     def test_import_root(self):
-        """Test 'import root-XXX as root1'"""
+        """Test 'import root-XXX as root1'."""
         try:
-            root1
+            root1  # noqa: B018
         except NameError:
             # root1 shouldn't exist yet
             pass
@@ -605,9 +604,9 @@ class TestImportReplacer(ImportReplacerHelper):
         )
 
     def test_import_mod(self):
-        """Test 'import root-XXX.mod-XXX as mod2'"""
+        """Test 'import root-XXX.mod-XXX as mod2'."""
         try:
-            mod1
+            mod1  # noqa: B018
         except NameError:
             # mod1 shouldn't exist yet
             pass
@@ -639,9 +638,9 @@ class TestImportReplacer(ImportReplacerHelper):
         )
 
     def test_import_mod_from_root(self):
-        """Test 'from root-XXX import mod-XXX as mod2'"""
+        """Test 'from root-XXX import mod-XXX as mod2'."""
         try:
-            mod2
+            mod2  # noqa: B018
         except NameError:
             # mod2 shouldn't exist yet
             pass
@@ -672,9 +671,9 @@ class TestImportReplacer(ImportReplacerHelper):
         )
 
     def test_import_root_and_mod(self):
-        """Test 'import root-XXX.mod-XXX' remapping both to root3.mod3"""
+        """Test 'import root-XXX.mod-XXX' remapping both to root3.mod3."""
         try:
-            root3
+            root3  # noqa: B018
         except NameError:
             # root3 shouldn't exist yet
             pass
@@ -723,7 +722,7 @@ class TestImportReplacer(ImportReplacerHelper):
         children to be imported.
         """
         try:
-            root4
+            root4  # noqa: B018
         except NameError:
             # root4 shouldn't exist yet
             pass
@@ -776,7 +775,7 @@ class TestImportReplacer(ImportReplacerHelper):
         reuse the intermediate lazy object.
         """
         try:
-            root5
+            root5  # noqa: B018
         except NameError:
             # root5 shouldn't exist yet
             pass
@@ -868,7 +867,7 @@ class TestImportReplacer(ImportReplacerHelper):
 
 
 class TestConvertImportToMap(TestCase):
-    """Directly test the conversion from import strings to maps"""
+    """Directly test the conversion from import strings to maps."""
 
     def check(self, expected, import_strings):
         proc = lazy_import.ImportProcessor()
@@ -877,8 +876,9 @@ class TestConvertImportToMap(TestCase):
         self.assertEqual(
             expected,
             proc.imports,
-            "Import of %r was not converted correctly"
-            " %s != %s" % (import_strings, expected, proc.imports),
+            "Import of {!r} was not converted correctly {} != {}".format(
+                import_strings, expected, proc.imports
+            ),
         )
 
     def test_import_one(self):
@@ -961,7 +961,7 @@ class TestConvertImportToMap(TestCase):
 
 
 class TestFromToMap(TestCase):
-    """Directly test the conversion of 'from foo import bar' syntax"""
+    """Directly test the conversion of 'from foo import bar' syntax."""
 
     def check_result(self, expected, from_strings):
         proc = lazy_import.ImportProcessor()
@@ -970,8 +970,9 @@ class TestFromToMap(TestCase):
         self.assertEqual(
             expected,
             proc.imports,
-            "Import of %r was not converted correctly"
-            " %s != %s" % (from_strings, expected, proc.imports),
+            "Import of {!r} was not converted correctly {} != {}".format(
+                from_strings, expected, proc.imports
+            ),
         )
 
     def test_from_one_import_two(self):
@@ -999,7 +1000,7 @@ class TestFromToMap(TestCase):
 
 
 class TestCanonicalize(TestCase):
-    """Test that we can canonicalize import texts"""
+    """Test that we can canonicalize import texts."""
 
     def check(self, expected, text):
         proc = lazy_import.ImportProcessor()
@@ -1007,7 +1008,7 @@ class TestCanonicalize(TestCase):
         self.assertEqual(
             expected,
             parsed,
-            "Incorrect parsing of text:\n%s\n%s\n!=\n%s" % (text, expected, parsed),
+            "Incorrect parsing of text:\n{}\n{}\n!=\n{}".format(text, expected, parsed),
         )
 
     def test_import_one(self):
@@ -1039,15 +1040,11 @@ class TestCanonicalize(TestCase):
         )
         self.check(
             ["import one", "import two, three", "from one import four"],
-            "import one\n" "import two, three\n" "from one import four",
+            "import one\nimport two, three\nfrom one import four",
         )
         self.check(
             ["import one", "import two, three", "from one import  four, "],
-            "import one\n"
-            "import two, three\n"
-            "from one import (\n"
-            "    four,\n"
-            "    )\n",
+            "import one\nimport two, three\nfrom one import (\n    four,\n    )\n",
         )
 
     def test_missing_trailing(self):
@@ -1060,7 +1057,7 @@ class TestCanonicalize(TestCase):
 
 
 class TestImportProcessor(TestCase):
-    """Test that ImportProcessor can turn import texts into lazy imports"""
+    """Test that ImportProcessor can turn import texts into lazy imports."""
 
     def check(self, expected, text):
         proc = lazy_import.ImportProcessor()
@@ -1068,7 +1065,9 @@ class TestImportProcessor(TestCase):
         self.assertEqual(
             expected,
             proc.imports,
-            "Incorrect processing of:\n%s\n%s\n!=\n%s" % (text, expected, proc.imports),
+            "Incorrect processing of:\n{}\n{}\n!=\n{}".format(
+                text, expected, proc.imports
+            ),
         )
 
     def test_import_one(self):
@@ -1124,7 +1123,7 @@ class TestImportProcessor(TestCase):
     def test_from_one_import_two(self):
         exp = {"two": (["one"], "two", {})}
         self.check(exp, "from one import two\n")
-        self.check(exp, "from one import (\n" "    two,\n" "    )\n")
+        self.check(exp, "from one import (\n    two,\n    )\n")
 
     def test_from_one_import_two_two(self):
         exp = {"two": (["one"], "two", {})}
@@ -1132,7 +1131,7 @@ class TestImportProcessor(TestCase):
         self.check(exp, "from one import (two)\n")
         self.check(exp, "from one import (two,)\n")
         self.check(exp, "from one import two as two\n")
-        self.check(exp, "from one import (\n" "    two,\n" "    )\n")
+        self.check(exp, "from one import (\n    two,\n    )\n")
 
     def test_from_many(self):
         exp = {
@@ -1141,7 +1140,7 @@ class TestImportProcessor(TestCase):
             "five": (["one", "two"], "four", {}),
         }
         self.check(
-            exp, "from one import two\n" "from one.two import three, four as five\n"
+            exp, "from one import two\nfrom one.two import three, four as five\n"
         )
         self.check(
             exp,
@@ -1217,7 +1216,7 @@ class TestImportProcessor(TestCase):
 class TestLazyImportProcessor(ImportReplacerHelper):
     def test_root(self):
         try:
-            root6
+            root6  # noqa: B018
         except NameError:
             pass  # root6 should not be defined yet
         else:
@@ -1252,18 +1251,15 @@ class TestLazyImportProcessor(ImportReplacerHelper):
         reuse the intermediate lazy object.
         """
         try:
-            submoda7
+            submoda7  # noqa: B018
         except NameError:
             pass  # submoda7 should not be defined yet
         else:
             self.fail("submoda7 was not supposed to exist yet")
 
-        text = (
-            """\
-import %(root_name)s.%(sub_name)s.%(submoda_name)s as submoda7
-"""
-            % self.__dict__
-        )
+        text = """\
+import {root_name}.{sub_name}.{submoda_name} as submoda7
+""".format(**self.__dict__)
         proc = lazy_import.ImportProcessor(InstrumentedImportReplacer)
         proc.lazy_import(scope=globals(), text=text)
 
@@ -1288,9 +1284,9 @@ import %(root_name)s.%(sub_name)s.%(submoda_name)s as submoda7
         )
 
     def test_lazy_import(self):
-        """Smoke test that lazy_import() does the right thing"""
+        """Smoke test that lazy_import() does the right thing."""
         try:
-            root8
+            root8  # noqa: B018
         except NameError:
             pass  # root8 should not be defined yet
         else:
@@ -1394,6 +1390,6 @@ class TestScopeReplacerReentrance(TestCase):
         replacer = lazy_import.ScopeReplacer({}, factory, "name")
 
         def racer():
-            replacer.foo
+            replacer.foo  # noqa: B018
 
         self.run_race(racer)
